pub enum Class {
C1,
C2,
C3,
C4,
C5,
}Expand description
The class of a StatusCode.
Variants
C1
Preliminary success.
The request has been processed but completion is pending.
C2
Complete success.
The request has been completed successfully, although based on the specific status code a fallback may have been taken.
C3
Client error.
The request was not successful, due to a syntactic or semantic error in the client-formatted request. The request should not be retried until the error condition in the request has been corrected.
C4
Scheduling error.
The request was not successful due to a semantic issue with the calendaring and scheduling service not directly related to the request itself.
C5
Service error.
The request was not successful because a service either did not exist, was not available, or was unsupported.
Implementations