Module string

Module string 

String data model types for RFC 5545.

Structs

CaselessStr
A case-insensitive str with repr(transparent) layout.
InvalidCharError
An error indicating that a string is not a valid iCalendar paramtext or TEXT value, because it contains an invalid character.
InvalidParamTextError
An error indicating that a string is not valid paramtext.
InvalidTextError
An error indicating that a string is not a valid TEXT value.
Name
A name in a content line (RFC 5545 3.1), or any value satisfying the iana-token grammar.
ParamText
A paramtext value as defined by RFC 5545 3.1.
ParamTextBuf
Text
A textual value (RFC 5545 3.3.11).
TextBuf

Enums

InvalidNameError
An error indicating that a string is not a valid iCalendar name.
NameKind
The kind of an iCalendar name.