Text

Struct Text 

pub struct Text(/* private fields */);
A textual value (RFC 5545 3.3.11).

This is the subset of str values that are permissible TEXT property values in iCalendar: all strings that do not contain ASCII control characters other than HTAB (U+0009) and LF (U+000A).

Implementations

Source

impl Text

pub fn new(input: &str) -> Result<&Self, InvalidTextError>

Source

impl Text

pub const fn as_str(&self) -> &str

Source

impl Text

pub const fn char_is_valid(c: char) -> bool

Returns true iff c is valid in a TEXT value.