pub enum Period<M = TimeFormat> {
Explicit {
start: DateTime<M>,
end: DateTime<M>,
},
Start {
start: DateTime<M>,
duration: Duration,
},
}Expand description
A period of time (RFC 5545 3.3.9).
Variants
Explicit
A period defined by explicit start and end datetimes.
Start
A period defined by a start datetime and a duration.