String data model types for RFC 5545.
Structs
- Caseless
Str - A case-insensitive
strwithrepr(transparent)layout. - Invalid
Char Error - An error indicating that a string is not a valid iCalendar
paramtextor TEXT value, because it contains an invalid character. - Invalid
Param Text Error - An error indicating that a string is not valid
paramtext. - Invalid
Text Error - An error indicating that a string is not a valid TEXT value.
- Name
- A name in a content line (RFC 5545 3.1), or any value satisfying the
iana-tokengrammar. - Param
Text - A
paramtextvalue as defined by RFC 5545 3.1. - Param
Text Buf - Text
- A textual value (RFC 5545 3.3.11).
- TextBuf
Enums
- Invalid
Name Error - An error indicating that a string is not a valid iCalendar name.
- Name
Kind - The kind of an iCalendar name.